==> insuideindoor-1.0.5%2B1.tar.gz: lib/itemLocationMap.dart <==
import 'package:flutter/material.dart';
import 'package:mapbox_gl/mapbox_gl.dart';


import 'MarkerList.dart';
import 'iteminfo.dart';

class ItemLocationMapScreen extends StatefulWidget {
  MapMarker mapMarker;
  List<MapMarker> mapMarkerList;
   ItemLocationMapScreen({Key? key,required this.mapMarker,required this.mapMarkerList}) : super(key: key);

  @override
  State<ItemLocationMapScreen> createState() => _ItemLocationMapScreenState();
}

class _ItemLocationMapScreenState extends State<ItemLocationMapScreen> {

  late MapboxMapController mapboxMapController;

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[

          Column(
            mainAxisSize: MainAxisSize.max,
            children: <Widget> [
              SizedBox(
                height: 80,
              ),
              Padding(
                padding: const EdgeInsets.only(right: 20.0, left: 20.0),
                child:
                SizedBox(
                    width: double.infinity,
                    height: 45,
                    child: TextField(
                      decoration: InputDecoration(
                          border: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(25.0),
                          ),
                          hintStyle:
                          TextStyle(color: Color.fromRGBO(51, 51, 51, 1)),
                          hintText: "Your Location",
                          contentPadding: const EdgeInsets.only(left: 20,right: 10,top: 10),
                          filled: true,
                          fillColor: Color.fromRGBO(255, 255, 255, 1)),
                    )) ,
              ),

              SizedBox(
                height: 10,
              ),

              Padding(
                padding: const EdgeInsets.only(right: 20.0, left: 20.0),
                child:
                SizedBox(
                    width: double.infinity,
                    height: 45,
                    child: TextField(
                      decoration: InputDecoration(
                          border: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(25.0),
                          ),
                          hintStyle:
                          TextStyle(color: Color.fromRGBO(51, 51, 51, 1)),
                          hintText: widget.mapMarker.title,
                          contentPadding: const EdgeInsets.only(left: 20,right: 10,top: 10),
                          filled: true,
                          fillColor: Color.fromRGBO(255, 255, 255, 1)),
                          onTap: (){
                               _navigateToNextScreen(context, false);
                          },
                    )) ,
              ),
              SizedBox(
                height: 20,
              ),

              Container(
                height: 500,
                width: double.infinity,
                child: MapboxMap(
                  accessToken: 'pk.eyJ1IjoibWVycmlsbC1hbW0iLCJhIjoiY2o4MnM0dm0wNTg5ODJ3bzNiajV1cHF2MyJ9.cLz-hmZiv5NbM4LGt-aBUA',
                    styleString: 'mapbox://styles/merrill-amm/ckz85ygks000r14qqgptjt1h5'
                    ,
                    initialCameraPosition:CameraPosition(target: LatLng
                    (widget.mapMarker.location.latitude , widget.mapMarker.location.longitude),
                    zoom: 18),
                  onMapCreated: (MapboxMapController mapController){
                    mapboxMapController = mapController;
                    print("marker"+widget.mapMarker.img);
                    mapboxMapController.addSymbol(SymbolOptions(
                      geometry: LatLng(widget.mapMarker.location.latitude , widget.mapMarker.location.longitude),
                      iconImage: widget.mapMarker.img,
                        iconSize: 02.1


                    ));
                  }
              ),



              )


            ],
          )
        ],
      ),
    );
  }

  void _navigateToNextScreen(BuildContext context, bool isNavToo) {
    Navigator.of(context).push(MaterialPageRoute(
      builder: (context) => SearchItemInfoScreen(
        mapMarkerList: widget.mapMarkerList,
        isNavTooView: isNavToo,
      ),
    ));
  }

}

==> insuideindoor-1.0.8%2B1.tar.gz: lib/itemLocationMap.dart <==
import 'package:flutter/material.dart';
import 'package:mapbox_gl/mapbox_gl.dart';


import 'MarkerList.dart';
import 'iteminfo.dart';

class ItemLocationMapScreen extends StatefulWidget {
  MapMarker mapMarker;
  List<MapMarker> mapMarkerList;
   ItemLocationMapScreen({Key? key,required this.mapMarker,required this.mapMarkerList}) : super(key: key);

  @override
  State<ItemLocationMapScreen> createState() => _ItemLocationMapScreenState();
}

class _ItemLocationMapScreenState extends State<ItemLocationMapScreen> {

  late MapboxMapController mapboxMapController;

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[

          Column(
            mainAxisSize: MainAxisSize.max,
            children: <Widget> [
              SizedBox(
                height: 80,
              ),
              Padding(
                padding: const EdgeInsets.only(right: 20.0, left: 20.0),
                child:
                SizedBox(
                    width: double.infinity,
                    height: 45,
                    child: TextField(
                      decoration: InputDecoration(
                          border: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(25.0),
                          ),
                          hintStyle:
                          TextStyle(color: Color.fromRGBO(51, 51, 51, 1)),
                          hintText: "Your Location",
                          contentPadding: const EdgeInsets.only(left: 20,right: 10,top: 10),
                          filled: true,
                          fillColor: Color.fromRGBO(255, 255, 255, 1)),
                    )) ,
              ),

              SizedBox(
                height: 10,
              ),

              Padding(
                padding: const EdgeInsets.only(right: 20.0, left: 20.0),
                child:
                SizedBox(
                    width: double.infinity,
                    height: 45,
                    child: TextField(
                      decoration: InputDecoration(
                          border: OutlineInputBorder(
                            borderRadius: BorderRadius.circular(25.0),
                          ),
                          hintStyle:
                          TextStyle(color: Color.fromRGBO(51, 51, 51, 1)),
                          hintText: widget.mapMarker.title,
                          contentPadding: const EdgeInsets.only(left: 20,right: 10,top: 10),
                          filled: true,
                          fillColor: Color.fromRGBO(255, 255, 255, 1)),
                          onTap: (){
                               _navigateToNextScreen(context, false);
                          },
                    )) ,
              ),
              SizedBox(
                height: 20,
              ),

              Container(
                height: 500,
                width: double.infinity,
                child: MapboxMap(
                  accessToken: 'pk.eyJ1IjoibWVycmlsbC1hbW0iLCJhIjoiY2o4MnM0dm0wNTg5ODJ3bzNiajV1cHF2MyJ9.cLz-hmZiv5NbM4LGt-aBUA',
                    styleString: 'mapbox://styles/merrill-amm/ckz85ygks000r14qqgptjt1h5',
                    initialCameraPosition:CameraPosition(target: LatLng
                    (widget.mapMarker.location.latitude , widget.mapMarker.location.longitude),
                    zoom: 18),
                  onMapCreated: (MapboxMapController mapController){
                    mapboxMapController = mapController;
                    print("marker"+widget.mapMarker.img);
                    mapboxMapController.addSymbol(SymbolOptions(
                      geometry: LatLng(widget.mapMarker.location.latitude , widget.mapMarker.location.longitude),
                      iconImage: widget.mapMarker.img,
                        iconSize: 02.1


                    ));
                  }
              ),



              )


            ],
          )
        ],
      ),
    );
  }

  void _navigateToNextScreen(BuildContext context, bool isNavToo) {
    Navigator.of(context).push(MaterialPageRoute(
      builder: (context) => SearchItemInfoScreen(
        mapMarkerList: widget.mapMarkerList,
        isNavTooView: isNavToo,
      ),
    ));
  }

}
